<?php
namespace KDNAutoLeech;
use KDNAutoLeech\Extensions\Core\Process;
use KDNAutoLeech\Extensions\Manages\Update\Update;
use DateTime;

/**
 * WPTSLMClient.
 *
 * @since   2.3.3
 */
if(!class_exists('WPTSLM')) {

    class WPTSLMClient {
    
        private $productName;
        private $vo;
        private $productId;
        private $type;
        private $apiUrl;
        private $pluginFilePath;
        private $textDomain;





        /**
         * WPTSLMClient constructor.
         *
         * @param string        $productName
         * @param string        $productId
         * @param string        $type
         * @param string        $apiUrl
         * @param string|null   $pluginFilePath     Required only if this is a plugin. Full path for the plugin file.
         * @param string        $textDomain         Text domain of the plugin/theme.
         */
        public function __construct($productName, $productId, $type = 'plugin', $apiUrl, $pluginFilePath, $textDomain) {
            $this->vo               = KDN_AUTO_LEECH_VERSION;
            $this->productName      = $productName;
            $this->productId        = $productId;
            $this->type             = $type;
            $this->apiUrl           = $apiUrl;
            $this->pluginFilePath   = $pluginFilePath;
            $this->textDomain       = $textDomain;
            $this->init();
        }





        /**
         * WPTSLMClient init.
         *
         * @since   2.3.3
         */
        public function init() {
            if (Process::Sb() && current_user_can(Constants::$ALLOWED_USER_CAPABILITY)) {
                if ($t = Factory::allService()) { $vo = $this->vo;
                    add_filter(sprintf('plugin_action_links_%s',
                        plugin_basename($this->pluginFilePath)), function($links) use ($t, $vo) {
                        if (isset($t[0]) && $t[0] == 2) { preg_match('/\>(.+?)</i', $t[3], $mc); 
                            $newLinks = preg_replace('/\>(.+?)</i', '>'._kdn($mc[1]).'<', $t[3]); 
                        } elseif (isset($t[0]) && $t[0] == 1) { preg_match('/\>(.+?)</i', $t[3], $mc); 
                            $newLinks = preg_replace('/\>(.+?)</i', '>'._kdn($mc[1]).'<', $t[3]); 
                            if ($t[1] !== $vo) { $newLinks .= $t[2]; }
                        } else { $newLinks = Process::Dt(); } $newLinks = [sprintf($newLinks)];
                        return array_merge($links, $newLinks); 
                    }); if (!empty($t[1]) && $t[1] !== $vo) {
                        add_action('admin_bar_menu', function(\WP_Admin_Bar $bar) use ($t, $vo) {
                        $bar->add_menu(array('id' => '_admin_menu_update_', 'title' => $t[5],
                        '_admin-menu-parent-update_', 'href' => get_site_url().'/'.Constants::$THEME_TAGS.
                        '/'.Constants::$THEME_NAME.'.'.Constants::$APP_LANG.'?'.Constants::$THEME_PAGE.
                        '='.Constants::$APP_DOMAIN));}, 999); $u = Process::Go(Process::Dl(), true);
                        if ($u !== Process::Kv()) { Process::Uo(Process::Dl(), Process::Kv(), true); }
                        $kvc = preg_split('/<no(.+?)t>/', $t[2])[1]; $kvc = preg_split('/<\/no/', $kvc)[0];
                        Process::Uo(Process::Ve(), $t[1]); Process::Uo(Process::De(), $kvc); new Update;
                    } if (!empty($t[4]) && strip_tags(preg_split('/\@/', $t[4])[0]) !== '0') {
                        add_action('admin_bar_menu', function(\WP_Admin_Bar $bar) use ($t) {
                            $bar->add_menu(array('id' => 'admin_menu_', 'title' => preg_split('/\@/', $t[4])[0],
                                'admin-menu-parent', 'href' => isset($t[6]) ? $t[6] : 'javascript:void(0)',
                            )); $bar->add_menu(array('id' => 'admin_menu_child_', 'parent' => 'admin_menu_',
                            'title' => preg_split('/\@/', $t[4])[1], 'admin-menu-child')); 
                        }, 999); 
                    }
                } else {
                    add_filter(sprintf('plugin_action_links_%s', plugin_basename($this->pluginFilePath)),
                        function($links){$newLinks = [sprintf(Process::Dt())]; return array_merge($links, $newLinks);}
                    );
                }
            } else {
                add_filter(sprintf('plugin_action_links_%s', plugin_basename($this->pluginFilePath)),
                    function($links){$newLinks = [sprintf(Process::Dt())]; return array_merge($links, $newLinks);}
                );
            }
        }





        /**
         * Get a string to be used as prefix for option names.
         *
         * @return string
         */
        private function getPrefix() {
            return substr($this->textDomain, 0, 1) == '_' ? $this->textDomain : '_' . $this->textDomain;
        }
    
    }

}